@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,7 +24,8 @@
  * @var array $data
  */
 
-$form = (new CForm())->setName('host_view');
+$form = (new CForm())
+	->setName('host_view');
 
 $table = (new CTableInfo());
 
@@ -59,11 +60,13 @@ foreach ($data['hosts'] as $hostid => $host) {
 		}
 	}
 
-	$problems_link = new CLink('', (new CUrl('zabbix.php'))
-		->setArgument('action', 'problem.view')
-		->setArgument('filter_name', '')
-		->setArgument('severities', $data['filter']['severities'])
-		->setArgument('hostids', [$host['hostid']]));
+	$problems_link = new CLink('',
+		(new CUrl('zabbix.php'))
+			->setArgument('action', 'problem.view')
+			->setArgument('severities', $data['filter']['severities'])
+			->setArgument('hostids', [$host['hostid']])
+			->setArgument('filter_set', '1')
+	);
 
 	$total_problem_count = 0;
 
@@ -119,7 +122,7 @@ foreach ($data['hosts'] as $hostid => $host) {
 					(new CUrl('zabbix.php'))
 						->setArgument('action', 'latest.view')
 						->setArgument('hostids', [$host['hostid']])
-						->setArgument('filter_name', '')
+						->setArgument('filter_set', '1')
 				)
 				: (new CSpan(_('Latest data')))->addClass(ZBX_STYLE_DISABLED),
 				CViewHelper::showNum($host['items_count'])
