@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,14 +27,27 @@
 				item_test_timeout, login_attempts, login_block, media_type_test_timeout, report_test_timeout,
 				script_timeout, snmptrap_logging, socket_timeout, uri_valid_schemes, url, validate_uri_schemes,
 				vault_provider, x_frame_options}) {
+			const $form = jQuery('#miscconfig-form');
+
 			$('#validate_uri_schemes').change(function() {
 				$('#uri_valid_schemes').prop('disabled', !this.checked);
 			});
 
+			$('#x_frame_header_enabled').change(function() {
+				$('#x_frame_options').prop('disabled', !this.checked);
+			});
+
 			$('#iframe_sandboxing_enabled').change(function() {
 				$('#iframe_sandboxing_exceptions').prop('disabled', !this.checked);
 			});
 
+			$form.on('submit', () => {
+				$form.trimValues(['#url', '#login_block', '#uri_valid_schemes', '#x_frame_options',
+					'#iframe_sandboxing_exceptions', '#socket_timeout', '#connect_timeout', '#media_type_test_timeout',
+					'#script_timeout', '#item_test_timeout', '#report_test_timeout'
+				]);
+			});
+
 			$("#resetDefaults").click(function() {
 				overlayDialogue({
 					'title': <?= json_encode(_('Reset confirmation')) ?>,
@@ -74,6 +87,11 @@
 									.prop('checked', validate_uri_schemes == 0 ? 'false' : 'true')
 									.change();
 								$('#uri_valid_schemes').val(uri_valid_schemes);
+								$('#x_frame_header_enabled')
+									.prop('checked',
+										<?= DB::getDefault('config', 'x_frame_options') === 'null' ? 'false' : 'true' ?>
+									)
+									.change();
 								$('#x_frame_options').val(x_frame_options);
 								$('#iframe_sandboxing_enabled')
 									.prop('checked', iframe_sandboxing_enabled == 0 ? 'false' : 'true')
