@@ -1,7 +1,7 @@
 <?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ window.host_edit_popup = {
 	dialogue: null,
 	form: null,
 
-	init({popup_url, form_name, host_interfaces, host_is_discovered, warning}) {
+	init({popup_url, form_name, host_interfaces, host_is_discovered, warnings}) {
 		this.overlay = overlays_stack.getById('host_edit');
 		this.dialogue = this.overlay.$dialogue[0];
 		this.form = this.overlay.$dialogue.$body[0].querySelector('form');
@@ -38,8 +38,12 @@ window.host_edit_popup = {
 
 		host_edit.init({form_name, host_interfaces, host_is_discovered});
 
-		if (warning !== null) {
-			const message_box = makeMessageBox('warning', [warning], null, true, false)[0];
+		if (warnings.length) {
+			const message_box = warnings.length == 1
+				? makeMessageBox('warning', warnings, null, true, false)[0]
+				: makeMessageBox('warning', warnings,
+						<?= json_encode(_('Cloned host parameter values have been modified.')) ?>, true, false
+					)[0];
 
 			this.form.parentNode.insertBefore(message_box, this.form);
 		}
@@ -49,7 +53,7 @@ window.host_edit_popup = {
 		this.removePopupMessages();
 
 		const fields = host_edit.preprocessFormFields(getFormFields(this.form), false);
-		const curl = new Curl(this.form.getAttribute('action'), false);
+		const curl = new Curl(this.form.getAttribute('action'));
 
 		fetch(curl.getUrl(), {
 			method: 'POST',
@@ -116,6 +120,7 @@ window.host_edit_popup = {
 
 		const curl = new Curl('zabbix.php');
 		curl.setArgument('action', 'host.massdelete');
+		curl.setArgument('<?= CCsrfTokenHelper::CSRF_TOKEN_NAME ?>', <?= json_encode(CCsrfTokenHelper::get('host')) ?>);
 
 		fetch(curl.getUrl(), {
 			method: 'POST',
