@@ -1,7 +1,7 @@
 <?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -84,27 +84,19 @@
 
 			const dialogue = overlay.$dialogue[0];
 
-			dialogue.addEventListener('dialogue.submit', (e) => {
-				postMessageOk(e.detail.title);
+			dialogue.addEventListener('dialogue.submit', (e) => this._reload(e.detail));
+			dialogue.addEventListener('dialogue.delete', (e) => this._reload(e.detail));
+		}
 
-				if ('messages' in e.detail) {
-					postMessageDetails('success', e.detail.messages);
-				}
+		_reload(success) {
+			postMessageOk(success.title);
 
-				location.href = location.href;
-			});
+			if ('messages' in success) {
+				postMessageDetails('success', success.messages);
+			}
 
-			dialogue.addEventListener('dialogue.delete', (e) => {
-				uncheckTableRows('sla');
-
-				postMessageOk(e.detail.title);
-
-				if ('messages' in e.detail) {
-					postMessageDetails('success', e.detail.messages);
-				}
-
-				location.href = location.href;
-			});
+			uncheckTableRows('sla');
+			location.href = location.href;
 		}
 
 		_enable(target, slaids) {
@@ -119,7 +111,7 @@
 			const curl = new Curl('zabbix.php');
 			curl.setArgument('action', 'sla.enable');
 
-			this._post(target, slaids, curl.getUrl());
+			this._post(target, slaids, curl);
 		}
 
 		_disable(target, slaids) {
@@ -134,7 +126,7 @@
 			const curl = new Curl('zabbix.php');
 			curl.setArgument('action', 'sla.disable');
 
-			this._post(target, slaids, curl.getUrl());
+			this._post(target, slaids, curl);
 		}
 
 		_delete(target, slaids) {
@@ -149,13 +141,17 @@
 			const curl = new Curl('zabbix.php');
 			curl.setArgument('action', 'sla.delete');
 
-			this._post(target, slaids, curl.getUrl());
+			this._post(target, slaids, curl);
 		}
 
-		_post(target, slaids, url) {
+		_post(target, slaids, curl) {
 			target.classList.add('is-loading');
 
-			return fetch(url, {
+			curl.setArgument('<?= CCsrfTokenHelper::CSRF_TOKEN_NAME ?>',
+				<?= json_encode(CCsrfTokenHelper::get('sla')) ?>
+			);
+
+			return fetch(curl.getUrl(), {
 				method: 'POST',
 				headers: {'Content-Type': 'application/json'},
 				body: JSON.stringify({slaids})
