@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-
 $output = [
-	'body' => (new CPartial('monitoring.host.view.html', $data))->getOutput()
+	'body' => (new CPartial('monitoring.host.view.html', $data))->getOutput(),
+	'groupids' => $data['filter']['groupids']
 ];
 
 if (($messages = getMessages()) !== null) {
