@@ -1,7 +1,7 @@
 <?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ if ($data['uncheck']) {
 	uncheckTableRows('latest');
 }
 
-$widget = (new CWidget())
+$html_page = (new CHtmlPage())
 	->setTitle(_('Latest data'))
 	->setWebLayoutMode($web_layout_mode)
 	->setDocUrl(CDocHelper::getUrl(CDocHelper::MONITORING_LATEST_VIEW))
@@ -64,19 +64,19 @@ if ($web_layout_mode == ZBX_LAYOUT_NORMAL) {
 
 	// Set javascript options for tab filter initialization in monitoring.latest.view.js.php file.
 	$data['filter_options'] = $filter->options;
-	$widget->addItem($filter);
+	$html_page->addItem($filter);
 }
 else {
 	$data['filter_options'] = null;
 }
 
-$widget->addItem(new CPartial('monitoring.latest.view.html', array_intersect_key($data,
-	array_flip(['filter', 'sort_field', 'sort_order', 'view_curl', 'paging', 'hosts', 'items', 'history', 'config',
-		'tags', 'maintenances', 'items_rw'
-	])
-)));
-
-$widget->show();
+$html_page
+	->addItem(new CPartial('monitoring.latest.view.html', array_intersect_key($data,
+		array_flip(['filter', 'sort_field', 'sort_order', 'view_curl', 'paging', 'hosts', 'items', 'history', 'config',
+			'tags', 'maintenances', 'items_rw'
+		])
+	)))
+	->show();
 
 (new CScriptTag('
 	view.init('.json_encode([
