@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,7 +26,9 @@
 
 $output = [
 	'body' => (new CPartial('monitoring.latest.view.html', $data['results']))->getOutput(),
-	'subfilter' => (new CPartial('monitoring.latest.subfilter', $data['subfilters']))->getOutput()
+	'subfilter' => (new CPartial('monitoring.latest.subfilter',
+		array_intersect_key($data, array_flip(['subfilters', 'subfilters_expanded']))
+	))->getOutput()
 ];
 
 if (($messages = getMessages()) !== null) {
