@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ require_once dirname(__FILE__).'/include/page_header.php';
 $fields = [
 	'imageid' =>	[T_ZBX_INT, O_MAND, P_SYS, DB_ID,				null],
 	'width' =>		[T_ZBX_INT, O_OPT, P_SYS,	BETWEEN(1, 2000),	null],
-	'height' =>		[T_ZBX_INT, O_OPT, P_SYS,	BETWEEN(1, 2000),	null],
+	'height' =>		[T_ZBX_INT, O_OPT, P_SYS,	BETWEEN(1, 2000),	null]
 ];
 check_fields($fields);
 
