@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -50,14 +50,16 @@ class CLocalApiClient extends CApiClient {
 	/**
 	 * Call the given API service method and return the response.
 	 *
-	 * @param string 	$requestApi			API name
-	 * @param string 	$requestMethod		API method
-	 * @param array 	$params				API parameters
-	 * @param string	$auth				Authentication token
+	 * @param string $requestApi     API name.
+	 * @param string $requestMethod  API method.
+	 * @param array  $params         API parameters.
+	 * @param array  $auth
+	 * @param int    $auth['type']   CJsonRpc::AUTH_TYPE_PARAM, CJsonRpc::AUTH_TYPE_HEADER, CJsonRpc::AUTH_TYPE_COOKIE
+	 * @param string $auth['auth']   Authentication token.
 	 *
 	 * @return CApiClientResponse
 	 */
-	public function callMethod($requestApi, $requestMethod, array $params, $auth) {
+	public function callMethod(string $requestApi, string $requestMethod, array $params, array $auth) {
 		global $DB;
 
 		$api = strtolower($requestApi);
@@ -84,24 +86,32 @@ class CLocalApiClient extends CApiClient {
 		$requiresAuthentication = $this->requiresAuthentication($api, $method);
 
 		// check that no authentication token is passed to methods that don't require it
-		if (!$requiresAuthentication && $auth !== null) {
-			$response->errorCode = ZBX_API_ERROR_PARAMETERS;
-			$response->errorMessage = _s('The "%1$s.%2$s" method must be called without the "auth" parameter.',
-				$requestApi, $requestMethod
-			);
+		if (!$requiresAuthentication) {
+			if ($auth['type'] == CJsonRpc::AUTH_TYPE_COOKIE) {
+				$auth['auth'] = null;
+			}
 
-			return $response;
+			if ($auth['auth'] !== null) {
+				$error = $auth['type'] == CJsonRpc::AUTH_TYPE_HEADER
+					? _('The "%1$s.%2$s" method must be called without authorization header.')
+					: _('The "%1$s.%2$s" method must be called without the "auth" parameter.');
+
+				$response->errorCode = ZBX_API_ERROR_PARAMETERS;
+				$response->errorMessage = _params($error, [$requestApi, $requestMethod]);
+
+				return $response;
+			}
 		}
 
 		$newTransaction = false;
 		try {
 			// authenticate
 			if ($requiresAuthentication) {
-				$this->authenticate($auth);
+				$this->authenticate($auth['auth']);
 
 				// check permissions
 				if (APP::getMode() === APP::EXEC_MODE_API && !$this->isAllowedMethod($api, $method)) {
-					$response->errorCode = ZBX_API_ERROR_PARAMETERS;
+					$response->errorCode = ZBX_API_ERROR_PERMISSIONS;
 					$response->errorMessage = _s('No permissions to call "%1$s.%2$s".', $requestApi, $requestMethod);
 
 					return $response;
@@ -164,85 +174,14 @@ class CLocalApiClient extends CApiClient {
 			throw new APIException(ZBX_API_ERROR_NO_AUTH, _('Not authorized.'));
 		}
 
-		if (strlen($auth) == 64) {
-			$this->tokenAuthentication($auth);
-			return;
-		}
+		$auth_data = strlen($auth) == 64 ? ['token' => $auth] : ['sessionid' => $auth];
 
-		$user = $this->serviceFactory->getObject('user')->checkAuthentication(['sessionid' => $auth]);
+		$user = $this->serviceFactory->getObject('user')->checkAuthentication($auth_data);
 		if (array_key_exists('debug_mode', $user)) {
 			$this->debug = $user['debug_mode'];
 		}
 	}
 
-	/**
-	 * Authenticates user based on token.
-	 *
-	 * @param string $auth_token
-	 *
-	 * @throws APIException
-	 */
-	protected function tokenAuthentication(string $auth_token) {
-		$api_tokens = DB::select('token', [
-			'output' => ['userid', 'expires_at', 'tokenid'],
-			'filter' => ['token' => hash('sha512', $auth_token), 'status' => ZBX_AUTH_TOKEN_ENABLED]
-		]);
-
-		if (!$api_tokens) {
-			usleep(10000);
-			throw new APIException(ZBX_API_ERROR_NO_AUTH, _('Not authorized.'));
-		}
-
-		[['expires_at' => $expires_at, 'userid' => $userid, 'tokenid' => $tokenid]] = $api_tokens;
-
-		if ($expires_at != 0 && $expires_at < time()) {
-			throw new APIException(ZBX_API_ERROR_PERMISSIONS, _('API token expired.'));
-		}
-
-		[['roleid' => $roleid, 'username' => $username]] = DB::select('users', [
-			'output' => ['roleid', 'username'],
-			'userids' => $userid
-		]);
-
-		[$type] = DBfetchColumn(DBselect('SELECT type FROM role WHERE roleid='.zbx_dbstr($roleid)), 'type');
-
-		$db_usrgrps = DBselect(
-			'SELECT g.debug_mode,g.users_status'.
-			' FROM usrgrp g,users_groups ug'.
-			' WHERE g.usrgrpid=ug.usrgrpid'.
-				' AND ug.userid='.$userid
-		);
-
-		$debug_mode = GROUP_DEBUG_MODE_DISABLED;
-		while ($db_usrgrp = DBfetch($db_usrgrps)) {
-			if ($db_usrgrp['users_status'] == GROUP_STATUS_DISABLED) {
-				throw new APIException(ZBX_API_ERROR_NO_AUTH, _('Not authorized.'));
-			}
-
-			if ($db_usrgrp['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
-				$debug_mode = GROUP_DEBUG_MODE_ENABLED;
-				break;
-			}
-		}
-
-		CApiService::$userData = [
-			'userid' => $userid,
-			'username' => $username,
-			'type' => $type,
-			'roleid' => $roleid,
-			'userip' => CWebUser::getIp(),
-			'sessionid' => $auth_token,
-			'debug_mode' => $debug_mode
-		];
-
-		$this->debug = ($debug_mode == GROUP_DEBUG_MODE_ENABLED);
-
-		DB::update('token', [
-			'values' => ['lastaccess' => time()],
-			'where' => ['tokenid' => $tokenid]
-		]);
-	}
-
 	/**
 	 * Returns true if the given API is valid.
 	 *
