@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,6 +24,9 @@
  */
 class CHistoryManager {
 
+	/**
+	 * @var bool
+	 */
 	private $primary_keys_enabled = false;
 
 	/**
@@ -33,7 +36,7 @@ class CHistoryManager {
 	 *
 	 * @return CHistoryManager
 	 */
-	public function setPrimaryKeysEnabled(bool $enabled = true) {
+	public function setPrimaryKeysEnabled(bool $enabled = true): CHistoryManager {
 		$this->primary_keys_enabled = $enabled;
 
 		return $this;
@@ -72,7 +75,12 @@ class CHistoryManager {
 	private function getItemsHavingValuesFromSql(array $items, $period = null) {
 		$results = [];
 
-		if ($period) {
+		if (CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY_GLOBAL) == 1) {
+			$hk_history = timeUnitToSeconds(CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY));
+			$period = $period !== null ? min($period, $hk_history) : $hk_history;
+		}
+
+		if ($period !== null) {
 			$period = time() - $period;
 		}
 
@@ -86,11 +94,10 @@ class CHistoryManager {
 
 		foreach ($itemids_by_type as $type => $type_itemids) {
 			$type_results = DBfetchColumn(DBselect(
-				'SELECT itemid'.
+				'SELECT DISTINCT itemid'.
 				' FROM '.self::getTableName($type).
 				' WHERE '.dbConditionInt('itemid', $type_itemids).
-					($period ? ' AND clock>'.$period : '').
-				' GROUP BY itemid'
+					($period !== null ? ' AND clock>'.$period : '')
 			), 'itemid');
 
 			$results += array_intersect_key($items, array_flip($type_results));
@@ -216,12 +223,18 @@ class CHistoryManager {
 	 * SQL specific implementation of getLastValues that makes use of primary key existence in history tables.
 	 *
 	 * @see CHistoryManager::getLastValues
+	 *
 	 * @return array  Of itemid => [up to $limit values].
 	 */
 	private function getLastValuesFromSqlWithPk(array $items, int $limit, ?int $period): array {
 		$results = [];
 
-		if ($period) {
+		if (CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY_GLOBAL) == 1) {
+			$hk_history = timeUnitToSeconds(CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY));
+			$period = $period !== null ? min($period, $hk_history) : $hk_history;
+		}
+
+		if ($period !== null) {
 			$period = time() - $period;
 		}
 
@@ -243,10 +256,10 @@ class CHistoryManager {
 				$history_table = self::getTableName($value_type);
 
 				$max_clock_per_item = DBselect(
-					'SELECT h.itemid, MAX(h.clock) AS clock'.
+					'SELECT h.itemid,MAX(h.clock) AS clock'.
 					' FROM '.$history_table.' h'.
 					' WHERE '.dbConditionId('h.itemid', array_column($items, 'itemid')).
-						($period ? ' AND h.clock > '.$period : '').
+						($period !== null ? ' AND h.clock>'.$period : '').
 					' GROUP BY h.itemid'
 				);
 
@@ -274,8 +287,8 @@ class CHistoryManager {
 					$db_values = DBselect('SELECT *'.
 						' FROM '.$history_table.' h'.
 						' WHERE h.itemid='.zbx_dbstr($item['itemid']).
-							($period ? ' AND h.clock > '.$period : '').
-						' ORDER BY h.clock DESC, h.ns DESC',
+							($period !== null ? ' AND h.clock>'.$period : '').
+						' ORDER BY h.clock DESC,h.ns DESC',
 						$limit
 					);
 
@@ -303,7 +316,12 @@ class CHistoryManager {
 	private function getLastValuesFromSql($items, $limit, $period) {
 		$results = [];
 
-		if ($period) {
+		if (CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY_GLOBAL) == 1) {
+			$hk_history = timeUnitToSeconds(CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY));
+			$period = $period !== null ? min($period, $hk_history) : $hk_history;
+		}
+
+		if ($period !== null) {
 			$period = time() - $period;
 		}
 
@@ -315,7 +333,7 @@ class CHistoryManager {
 					'SELECT MAX(h.clock)'.
 					' FROM '.self::getTableName($item['value_type']).' h'.
 					' WHERE h.itemid='.zbx_dbstr($item['itemid']).
-						($period ? ' AND h.clock>'.$period : '')
+						($period !== null ? ' AND h.clock>'.$period : '')
 				), false);
 
 				if ($clock_max) {
@@ -345,7 +363,7 @@ class CHistoryManager {
 					'SELECT *'.
 					' FROM '.self::getTableName($item['value_type']).' h'.
 					' WHERE h.itemid='.zbx_dbstr($item['itemid']).
-						($period ? ' AND h.clock>'.$period : '').
+						($period !== null ? ' AND h.clock>'.$period : '').
 					' ORDER BY h.clock DESC',
 					$limit + 1
 				));
@@ -438,7 +456,6 @@ class CHistoryManager {
 			'size' => 1
 		];
 
-		$history_period = timeUnitToSeconds(CSettingsHelper::get(CSettingsHelper::HISTORY_PERIOD));
 		$filters = [
 			[
 				[
@@ -468,8 +485,9 @@ class CHistoryManager {
 				[
 					'range' => [
 						'clock' => [
-							'lt' => $clock
-						] + ($history_period ? ['gte' => $clock - $history_period] : [])
+							'lt' => $clock,
+							'gte' => $clock - timeUnitToSeconds(CSettingsHelper::get(CSettingsHelper::HISTORY_PERIOD))
+						]
 					]
 				]
 			]
@@ -505,6 +523,13 @@ class CHistoryManager {
 	 * @return array|null  Item data at specified time of first data before specified time. null if data is not found.
 	 */
 	private function getValueAtFromSqlWithPk(array $item, $clock, $ns): ?array {
+		$hk_history_global = CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY_GLOBAL);
+		$hk_history = timeUnitToSeconds(CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY));
+
+		if ($hk_history_global == 1 && $clock <= time() - $hk_history) {
+			return null;
+		}
+
 		$history_table = self::getTableName($item['value_type']);
 
 		$sql = 'SELECT *'.
@@ -518,13 +543,18 @@ class CHistoryManager {
 			return $row;
 		}
 
-		$history_period = timeUnitToSeconds(CSettingsHelper::get(CSettingsHelper::HISTORY_PERIOD));
+		$time_from = $clock - timeUnitToSeconds(CSettingsHelper::get(CSettingsHelper::HISTORY_PERIOD));
+
+		if ($hk_history_global == 1) {
+			$time_from = max($time_from, time() - $hk_history + 1);
+		}
+
 		$sql = 'SELECT *'.
 			' FROM '.$history_table.
 			' WHERE itemid='.zbx_dbstr($item['itemid']).
 				' AND clock<'.zbx_dbstr($clock).
-				($history_period ? ' AND clock >= '.zbx_dbstr($clock - $history_period) : '').
-			' ORDER BY clock DESC, ns DESC';
+				' AND clock>='.zbx_dbstr($time_from).
+			' ORDER BY clock DESC,ns DESC';
 
 		if (($row = DBfetch(DBselect($sql, 1))) !== false) {
 			return $row;
@@ -539,6 +569,13 @@ class CHistoryManager {
 	 * @see CHistoryManager::getValueAt
 	 */
 	private function getValueAtFromSql(array $item, $clock, $ns) {
+		$hk_history_global = CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY_GLOBAL);
+		$hk_history = timeUnitToSeconds(CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY));
+
+		if ($hk_history_global == 1 && $clock <= time() - $hk_history) {
+			return null;
+		}
+
 		$result = null;
 		$table = self::getTableName($item['value_type']);
 
@@ -568,12 +605,17 @@ class CHistoryManager {
 		}
 
 		if ($max_clock == 0) {
-			$history_period = timeUnitToSeconds(CSettingsHelper::get(CSettingsHelper::HISTORY_PERIOD));
+			$time_from = $clock - timeUnitToSeconds(CSettingsHelper::get(CSettingsHelper::HISTORY_PERIOD));
+
+			if ($hk_history_global == 1) {
+				$time_from = max($time_from, time() - $hk_history + 1);
+			}
+
 			$sql = 'SELECT MAX(clock) AS clock'.
 					' FROM '.$table.
 					' WHERE itemid='.zbx_dbstr($item['itemid']).
 						' AND clock<'.zbx_dbstr($clock).
-						($history_period ? ' AND clock>='.zbx_dbstr($clock - $history_period) : '');
+						' AND clock>='.zbx_dbstr($time_from);
 
 			if (($row = DBfetch(DBselect($sql))) !== false) {
 				$max_clock = $row['clock'];
@@ -689,7 +731,7 @@ class CHistoryManager {
 		];
 
 		// Clock value is divided by 1000 as it is stored as milliseconds.
-		$formula = '((doc[\'clock\'].date.getMillis()/1000) - ((doc[\'clock\'].date.getMillis()/1000)%params.interval))';
+		$formula = "doc['clock'].value.getMillis()/1000-doc['clock'].value.getMillis()/1000%params.interval";
 
 		$query['aggs']['group_by_itemid']['aggs'] = [
 			'group_by_script' => [
@@ -772,6 +814,11 @@ class CHistoryManager {
 
 		$result = [];
 
+		$hk_history_global = CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY_GLOBAL);
+		$hk_history = timeUnitToSeconds(CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY));
+		$hk_trends_global = CHousekeepingHelper::get(CHousekeepingHelper::HK_TRENDS_GLOBAL);
+		$hk_trends = timeUnitToSeconds(CHousekeepingHelper::get(CHousekeepingHelper::HK_TRENDS));
+
 		foreach ($items_by_table as $value_type => $items_by_source) {
 			foreach ($items_by_source as $source => $itemids) {
 				$sql_select = ['itemid'];
@@ -806,6 +853,10 @@ class CHistoryManager {
 							break;
 					}
 					$sql_from = ($value_type == ITEM_VALUE_TYPE_UINT64) ? 'history_uint' : 'history';
+
+					$_time_from = $hk_history_global == 1
+						? max($time_from, time() - $hk_history + 1)
+						: $time_from;
 				}
 				else {
 					switch ($function) {
@@ -832,17 +883,21 @@ class CHistoryManager {
 							break;
 					}
 					$sql_from = ($value_type == ITEM_VALUE_TYPE_UINT64) ? 'trends_uint' : 'trends';
+
+					$_time_from = $hk_trends_global == 1
+						? max($time_from, time() - $hk_trends + 1)
+						: $time_from;
 				}
 
 				$sql = 'SELECT '.implode(', ', $sql_select).
 					' FROM '.$sql_from.
 					' WHERE '.dbConditionInt('itemid', $itemids).
-					' AND clock >= '.zbx_dbstr($time_from).
-					' AND clock <= '.zbx_dbstr($time_to).
+					' AND clock>='.zbx_dbstr($_time_from).
+					' AND clock<='.zbx_dbstr($time_to).
 					' GROUP BY '.implode(', ', $sql_group_by);
 
 				if ($function == AGGREGATE_FIRST || $function == AGGREGATE_LAST) {
-					$sql = 'SELECT DISTINCT h.itemid, h.'.($source === 'history' ? 'value' : 'value_avg').' AS value, h.clock, hi.tick'.
+					$sql = 'SELECT DISTINCT h.itemid,h.'.($source === 'history' ? 'value' : 'value_avg').' AS value,h.clock,hi.tick'.
 						' FROM '.$sql_from.' h'.
 						' JOIN('.$sql.') hi ON h.itemid = hi.itemid AND h.clock = hi.clock';
 				}
@@ -958,8 +1013,7 @@ class CHistoryManager {
 		];
 
 		if ($width !== null) {
-			$size = $time_to - $time_from;
-			$delta = $size - $time_from % $size;
+			$period = $time_to - $time_from;
 
 			// Additional grouping for line graphs.
 			$aggs['max_clock'] = [
@@ -969,15 +1023,14 @@ class CHistoryManager {
 			];
 
 			// Clock value is divided by 1000 as it is stored as milliseconds.
-			$formula = 'Math.floor((params.width*((doc[\'clock\'].value.getMillis()/1000+params.delta)%params.size))'.
-					'/params.size)';
+			$formula = "Math.round(params.width*(doc['clock'].value.getMillis()/1000-params.time_from)/params.period)";
 
 			$script = [
 				'inline' => $formula,
 				'params' => [
 					'width' => (int)$width,
-					'delta' => $delta,
-					'size' => $size
+					'time_from' => $time_from,
+					'period' => $period
 				]
 			];
 			$aggs = [
@@ -1066,12 +1119,10 @@ class CHistoryManager {
 		$sql_select_extra = '';
 
 		if ($width !== null) {
-			$size = $time_to - $time_from;
-			$delta = $size - $time_from % $size;
+			$period = $time_to - $time_from;
 
 			// Required for 'group by' support of Oracle.
-			$calc_field = 'round('.$width.'*'.zbx_sql_mod(zbx_dbcast_2bigint('clock').'+'.$delta, $size)
-					.'/('.$size.'),0)';
+			$calc_field = 'round('.$width.'*('.zbx_dbcast_2bigint('clock').'-'.$time_from.')/'.$period.',0)';
 
 			$sql_select_extra = ','.$calc_field.' AS i';
 			$group_by .= ','.$calc_field;
@@ -1079,28 +1130,44 @@ class CHistoryManager {
 
 		$results = [];
 
+		$hk_history_global = CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY_GLOBAL);
+		$hk_history = timeUnitToSeconds(CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY));
+		$hk_trends_global = CHousekeepingHelper::get(CHousekeepingHelper::HK_TRENDS_GLOBAL);
+		$hk_trends = timeUnitToSeconds(CHousekeepingHelper::get(CHousekeepingHelper::HK_TRENDS));
+
 		foreach ($items as $item) {
 			if ($item['source'] === 'history') {
 				$sql_select = 'COUNT(*) AS count,AVG(value) AS avg,MIN(value) AS min,MAX(value) AS max';
-				$sql_from = ($item['value_type'] == ITEM_VALUE_TYPE_UINT64) ? 'history_uint' : 'history';
+				$sql_from = $item['value_type'] == ITEM_VALUE_TYPE_UINT64 ? 'history_uint' : 'history';
+
+				$_time_from = $hk_history_global == 1
+					? max($time_from, time() - $hk_history + 1)
+					: $time_from;
 			}
 			else {
 				$sql_select = 'SUM(num) AS count,AVG(value_avg) AS avg,MIN(value_min) AS min,MAX(value_max) AS max';
 				$sql_from = ($item['value_type'] == ITEM_VALUE_TYPE_UINT64) ? 'trends_uint' : 'trends';
+
+				$_time_from = $hk_trends_global == 1
+					? max($time_from, time() - $hk_trends + 1)
+					: $time_from;
 			}
 
-			$result = DBselect(
-				'SELECT itemid,'.$sql_select.$sql_select_extra.',MAX(clock) AS clock'.
-				' FROM '.$sql_from.
-				' WHERE itemid='.zbx_dbstr($item['itemid']).
-					' AND clock>='.zbx_dbstr($time_from).
-					' AND clock<='.zbx_dbstr($time_to).
-				' GROUP BY '.$group_by
-			);
-
 			$data = [];
-			while (($row = DBfetch($result)) !== false) {
-				$data[] = $row;
+
+			if ($_time_from <= $time_to) {
+				$result = DBselect(
+					'SELECT itemid,'.$sql_select.$sql_select_extra.',MAX(clock) AS clock'.
+					' FROM '.$sql_from.
+					' WHERE itemid='.zbx_dbstr($item['itemid']).
+						' AND clock>='.zbx_dbstr($_time_from).
+						' AND clock<='.zbx_dbstr($time_to).
+					' GROUP BY '.$group_by
+				);
+
+				while (($row = DBfetch($result)) !== false) {
+					$data[] = $row;
+				}
 			}
 
 			$results[$item['itemid']]['source'] = $item['source'];
@@ -1186,6 +1253,11 @@ class CHistoryManager {
 	 * @see CHistoryManager::getAggregatedValue
 	 */
 	private function getAggregatedValueFromSql(array $item, $aggregation, $time_from) {
+		if (CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY_GLOBAL) == 1) {
+			$hk_history = timeUnitToSeconds(CHousekeepingHelper::get(CHousekeepingHelper::HK_HISTORY));
+			$time_from = max($time_from, time() - $hk_history);
+		}
+
 		$result = DBselect(
 			'SELECT '.$aggregation.'(value) AS value'.
 			' FROM '.self::getTableName($item['value_type']).
@@ -1254,7 +1326,7 @@ class CHistoryManager {
 	private function deleteHistoryFromSql(array $items) {
 		global $DB;
 
-		$item_tables = array_map('self::getTableName', array_unique($items));
+		$item_tables = array_map([self::class, 'getTableName'], array_unique($items));
 		$table_names = array_flip(self::getTableName());
 
 		if (in_array(ITEM_VALUE_TYPE_UINT64, $items)) {
@@ -1412,7 +1484,7 @@ class CHistoryManager {
 		}
 
 		$indices = [];
-		$endponts = [];
+		$endpoints = [];
 
 		foreach (array_unique($value_types) as $type) {
 			if (self::getDataSourceType($type) === ZBX_HISTORY_SOURCE_ELASTIC) {
@@ -1422,11 +1494,11 @@ class CHistoryManager {
 
 		foreach ($indices as $type => $index) {
 			if (($url = self::getElasticsearchUrl($index)) !== null) {
-				$endponts[$type] = $url.$index.'*/'.$action;
+				$endpoints[$type] = $url.$index.'*/'.$action;
 			}
 		}
 
-		return $endponts;
+		return $endpoints;
 	}
 
 	/**
