@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -31,11 +31,9 @@ class CMultiSelect extends CTag {
 	const SEARCH_METHOD = 'multiselect.get';
 
 	/**
-	 * Supported preselect types.
-	 *
-	 * @param array
+	 * @var array
 	 */
-	protected $preselect_fields = ['hosts', 'hostgroups', 'templategroups'];
+	protected $params = [];
 
 	/**
 	 * @param array $options['objectOptions']  An array of parameters to be added to the request URL.
@@ -56,8 +54,7 @@ class CMultiSelect extends CTag {
 			->addItem((new CDiv())
 				->setAttribute('aria-live', 'assertive')
 				->setAttribute('aria-atomic', 'true')
-			)
-			->js_event_name = sprintf('multiselect_%s_init', $this->getId());
+			);
 
 		if (array_key_exists('disabled', $options) && $options['disabled']) {
 			$this->setAttribute('aria-disabled', 'true');
@@ -87,6 +84,10 @@ class CMultiSelect extends CTag {
 			]
 		];
 
+		if (array_key_exists('multiselect_id', $options)) {
+			$params['multiselect_id'] = $options['multiselect_id'];
+		}
+
 		if (array_key_exists('data', $options)) {
 			$params['data'] = zbx_cleanHashes($options['data']);
 		}
@@ -97,18 +98,17 @@ class CMultiSelect extends CTag {
 			}
 		}
 
-		if (array_key_exists('autosuggest', $options)) {
-			if (array_key_exists('filter_preselect_fields', $options['autosuggest'])) {
-				$params['autosuggest']['filter_preselect_fields'] = $options['autosuggest']['filter_preselect_fields'];
-			}
+		if (array_key_exists('autosuggest', $options)
+				&& array_key_exists('filter_preselect', $options['autosuggest'])) {
+			$params['autosuggest']['filter_preselect'] = $options['autosuggest']['filter_preselect'];
 		}
 
 		if (array_key_exists('custom_select', $options)) {
 			$params['custom_select'] = $options['custom_select'];
 		}
 		elseif (array_key_exists('popup', $options)) {
-			if (array_key_exists('filter_preselect_fields', $options['popup'])) {
-				$params['popup']['filter_preselect_fields'] = $options['popup']['filter_preselect_fields'];
+			if (array_key_exists('filter_preselect', $options['popup'])) {
+				$params['popup']['filter_preselect'] = $options['popup']['filter_preselect'];
 			}
 
 			if (array_key_exists('parameters', $options['popup'])) {
@@ -152,8 +152,8 @@ class CMultiSelect extends CTag {
 	 * @return array
 	 */
 	protected function mapOptions(array $options) {
-		$valid_fields = ['name', 'object_name', 'multiple', 'disabled', 'default_value', 'data', 'add_new',
-			'add_post_js', 'styles', 'popup', 'custom_select', 'placeholder', 'autosuggest'
+		$valid_fields = ['name', 'object_name', 'multiselect_id', 'multiple', 'disabled', 'default_value', 'data',
+			'add_new', 'add_post_js', 'styles', 'popup', 'custom_select', 'placeholder', 'autosuggest'
 		];
 
 		foreach ($options as $field => $value) {
@@ -166,6 +166,7 @@ class CMultiSelect extends CTag {
 		$mappings = [
 			'name' => 'name',
 			'object_name' => 'object_name',
+			'multiselect_id' => 'multiselect_id',
 			'disabled' => 'disabled',
 			'default_value' => 'defaultValue',
 			'data' => 'data',
@@ -187,7 +188,7 @@ class CMultiSelect extends CTag {
 		}
 
 		if (array_key_exists('autosuggest', $options)) {
-			$valid_fields = ['filter_preselect_fields'];
+			$valid_fields = ['filter_preselect'];
 
 			foreach (array_keys($options['autosuggest']) as $field) {
 				if (!in_array($field, $valid_fields)) {
@@ -195,19 +196,16 @@ class CMultiSelect extends CTag {
 				}
 			}
 
-			if (array_key_exists('filter_preselect_fields', $options['autosuggest'])) {
-				if (is_array($options['autosuggest']['filter_preselect_fields'])) {
-					foreach ($options['autosuggest']['filter_preselect_fields'] as $field => $value) {
-						if (in_array($field, $this->preselect_fields) && is_string($value) && $value !== '') {
-							$mapped_options['autosuggest']['filter_preselect_fields'][$field] = $value;
-						}
-						else {
-							error('invalid property: $options[\'autosuggest\'][\'filter_preselect_fields\'][\''.$field.'\']');
-						}
+			if (array_key_exists('filter_preselect', $options['autosuggest'])) {
+				if (is_array($options['autosuggest']['filter_preselect'])) {
+					if (self::validateFilterPreselect($options['autosuggest']['filter_preselect'],
+							'$options[\'autosuggest\'][\'filter_preselect\']')) {
+						$mapped_options['autosuggest']['filter_preselect']
+							= $options['autosuggest']['filter_preselect'];
 					}
 				}
 				else {
-					error('invalid property: $options[\'autosuggest\'][\'filter_preselect_fields\']');
+					error('invalid property: $options[\'autosuggest\'][\'filter_preselect\']');
 				}
 			}
 		}
@@ -218,32 +216,28 @@ class CMultiSelect extends CTag {
 			$mapped_options['custom_select'] = true;
 		}
 		elseif (array_key_exists('popup', $options)) {
-			$popup_parameters = [];
+			$valid_fields = ['parameters', 'filter_preselect'];
 
-			$valid_fields = ['parameters', 'filter_preselect_fields'];
-
-			foreach ($options['popup'] as $field => $value) {
+			foreach (array_keys($options['popup']) as $field) {
 				if (!in_array($field, $valid_fields)) {
 					error('unsupported option: $options[\'popup\'][\''.$field.'\']');
 				}
 			}
 
-			if (array_key_exists('filter_preselect_fields', $options['popup'])) {
-				if (is_array($options['popup']['filter_preselect_fields'])) {
-					foreach ($options['popup']['filter_preselect_fields'] as $field => $value) {
-						if (in_array($field, $this->preselect_fields) && is_string($value) && $value !== '') {
-							$mapped_options['popup']['filter_preselect_fields'][$field] = $value;
-						}
-						else {
-							error('invalid property: $options[\'popup\'][\'filter_preselect_fields\'][\''.$field.'\']');
-						}
+			if (array_key_exists('filter_preselect', $options['popup'])) {
+				if (is_array($options['popup']['filter_preselect'])) {
+					if (self::validateFilterPreselect($options['popup']['filter_preselect'],
+							'$options[\'popup\'][\'filter_preselect\']')) {
+						$mapped_options['popup']['filter_preselect'] = $options['popup']['filter_preselect'];
 					}
 				}
 				else {
-					error('invalid property: $options[\'popup\'][\'filter_preselect_fields\']');
+					error('invalid property: $options[\'popup\'][\'filter_preselect\']');
 				}
 			}
 
+			$popup_parameters = [];
+
 			if (array_key_exists('parameters', $options['popup'])) {
 				$parameters = $options['popup']['parameters'];
 
@@ -253,7 +247,7 @@ class CMultiSelect extends CTag {
 					'with_items', 'with_simple_graph_items', 'with_simple_graph_item_prototypes', 'with_triggers',
 					'value_types', 'excludeids', 'disableids', 'enrich_parent_groups', 'with_monitored_items',
 					'with_httptests', 'user_type', 'disable_selected', 'hostids', 'with_inherited', 'context',
-					'enabled_only'
+					'enabled_only', 'group_status'
 				];
 
 				foreach ($parameters as $field => $value) {
@@ -413,6 +407,11 @@ class CMultiSelect extends CTag {
 					$popup_parameters['enabled_only'] = '1';
 					$autocomplete_parameters['enabled_only'] = true;
 				}
+
+				if (array_key_exists('group_status', $parameters)) {
+					$popup_parameters['group_status'] = $parameters['group_status'];
+					$autocomplete_parameters['group_status'] = $parameters['group_status'];
+				}
 			}
 
 			$mapped_options['popup']['parameters'] = $popup_parameters;
@@ -422,4 +421,38 @@ class CMultiSelect extends CTag {
 
 		return $mapped_options;
 	}
+
+	protected static function validateFilterPreselect(array $field, string $path): bool {
+		$is_valid = true;
+
+		foreach (array_keys($field) as $option) {
+			if (!in_array($option, ['id', 'submit_as', 'submit_parameters', 'multiple'])) {
+				error('unsupported option: '.$path.'[\''.$option.'\']');
+				$is_valid = false;
+			}
+		}
+
+		if (!array_key_exists('id', $field) || !is_string($field['id']) || $field['id'] === '') {
+			error('invalid property: '.$path.'[\'id\']');
+			$is_valid = false;
+		}
+
+		if (array_key_exists('submit_as', $field)
+				&& (!is_string($field['submit_as']) || $field['submit_as'] === '')) {
+			error('invalid property: '.$path.'[\'submit_as\']');
+			$is_valid = false;
+		}
+
+		if (array_key_exists('submit_parameters', $field) && !is_array($field['submit_parameters'])) {
+			error('invalid property: '.$path.'[\'submit_parameters\']');
+			$is_valid = false;
+		}
+
+		if (array_key_exists('multiple', $field) && !is_bool($field['multiple'])) {
+			error('invalid property: '.$path.'[\'multiple\']');
+			$is_valid = false;
+		}
+
+		return $is_valid;
+	}
 }
