@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@ class CRadioButtonList extends CList {
 	private $readonly;
 	private $modern;
 	private $autofocused;
+	private $autocomplete = true;
 
 	/**
 	 * Array of value elements.
@@ -99,7 +100,7 @@ class CRadioButtonList extends CList {
 		return $this;
 	}
 
-	public function setModern($modern) {
+	public function setModern($modern = true) {
 		$this->modern = $modern;
 
 		return $this;
@@ -141,6 +142,10 @@ class CRadioButtonList extends CList {
 				}
 			}
 
+			if (!$this->autocomplete) {
+				$radio->setAttribute('autocomplete', 'off');
+			}
+
 			if ($this->modern) {
 				$this->addItem((new CListItem([$radio, new CLabel($value['name'], $value['id'])]))->addClass(
 					array_key_exists('class', $value) ? $value['class'] : null
@@ -178,4 +183,13 @@ class CRadioButtonList extends CList {
 
 		return parent::setAttribute($name, $value);
 	}
+
+	/**
+	 * Prevent browser to autocomplete input element.
+	 */
+	public function disableAutocomplete() {
+		$this->autocomplete = false;
+
+		return $this;
+	}
 }
