@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -22,6 +22,6 @@
 class CSvgGroup extends CSvgTag {
 
 	public function __construct() {
-		parent::__construct('g', true);
+		parent::__construct('g');
 	}
 }
