@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -291,6 +291,27 @@ class CHostImporter extends CImporter {
 	 * @throws Exception
 	 */
 	protected function resolveHostReferences(array $host): array {
+		$hostid = $this->referencer->findHostidByHost($host['host']);
+
+		if ($hostid !== null) {
+			$host['hostid'] = $hostid;
+
+			if (array_key_exists('macros', $host)) {
+				foreach ($host['macros'] as &$macro) {
+					$hostmacroid = $this->referencer->findHostMacroid($hostid, $macro['macro']);
+
+					if ($hostmacroid !== null) {
+						$macro['hostmacroid'] = $hostmacroid;
+					}
+				}
+				unset($macro);
+			}
+		}
+
+		if (!$this->options['hosts']['createMissing'] && !$this->options['hosts']['updateExisting']) {
+			return $host;
+		}
+
 		foreach ($host['groups'] as $index => $group) {
 			$groupid = $this->referencer->findHostGroupidByName($group['name']);
 
@@ -316,23 +337,6 @@ class CHostImporter extends CImporter {
 			$host['proxy_hostid'] = $proxyid;
 		}
 
-		$hostid = $this->referencer->findHostidByHost($host['host']);
-
-		if ($hostid !== null) {
-			$host['hostid'] = $hostid;
-
-			if (array_key_exists('macros', $host)) {
-				foreach ($host['macros'] as &$macro) {
-					$hostmacroid = $this->referencer->findHostMacroid($hostid, $macro['macro']);
-
-					if ($hostmacroid !== null) {
-						$macro['hostmacroid'] = $hostmacroid;
-					}
-				}
-				unset($macro);
-			}
-		}
-
 		return $host;
 	}
 
