@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -53,20 +53,16 @@ class CScreenDiscovery extends CScreenBase {
 
 		$sort_field = $this->data['sort'];
 		$sort_order = $this->data['sortorder'];
-		$druleid = $this->data['druleid'];
 
-		$options = [
+		$drules = API::DRule()->get([
 			'output' => ['druleid', 'name'],
 			'selectDHosts' => ['dhostid', 'status', 'lastup', 'lastdown'],
+			'druleids' => (array_key_exists('filter_druleids', $this->data) && $this->data['filter_druleids'])
+				? $this->data['filter_druleids']
+				: null,
 			'filter' => ['status' => DRULE_STATUS_ACTIVE],
 			'preservekeys' => true
-		];
-
-		if ($druleid != 0) {
-			$options['druleids'] = [$druleid];
-		}
-
-		$drules = API::DRule()->get($options);
+		]);
 
 		order_result($drules, 'name');
 
@@ -82,7 +78,7 @@ class CScreenDiscovery extends CScreenBase {
 
 		// user macros
 		$macros = API::UserMacro()->get([
-			'output' => ['macro', 'value'],
+			'output' => ['macro', 'value', 'type'],
 			'globalmacro' => true
 		]);
 		$macros = zbx_toHash($macros, 'macro');
@@ -99,7 +95,7 @@ class CScreenDiscovery extends CScreenBase {
 			$key_ = $dchecks[$dservice['dcheckid']]['key_'];
 			if ($key_ !== '') {
 				if (array_key_exists($key_, $macros)) {
-					$key_ = $macros[$key_]['value'];
+					$key_ = CMacrosResolverGeneral::getMacroValue($macros[$key_]);
 				}
 				$key_ = ': '.$key_;
 			}
@@ -125,15 +121,13 @@ class CScreenDiscovery extends CScreenBase {
 		];
 
 		foreach ($services as $name => $foo) {
-			$header[] = (new CColHeader($name))
-				->addClass('vertical_rotation')
+			$header[] = (new CSpan($name))
+				->addClass(ZBX_STYLE_TEXT_VERTICAL)
 				->setTitle($name);
 		}
 
 		// create table
-		$table = (new CTableInfo())
-			->makeVerticalRotation()
-			->setHeader($header);
+		$table = (new CTableInfo())->setHeader($header);
 
 		foreach ($drules as $drule) {
 			$discovery_info = [];
@@ -157,7 +151,7 @@ class CScreenDiscovery extends CScreenBase {
 					$hostName = '';
 
 					$host = reset($dservices[$dservice['dserviceid']]['hosts']);
-					if (!is_null($host)) {
+					if ($host) {
 						$hostName = $host['name'];
 					}
 
@@ -197,7 +191,7 @@ class CScreenDiscovery extends CScreenBase {
 					$key_ = $dchecks[$dservice['dcheckid']]['key_'];
 					if ($key_ !== '') {
 						if (array_key_exists($key_, $macros)) {
-							$key_ = $macros[$key_]['value'];
+							$key_ = CMacrosResolverGeneral::getMacroValue($macros[$key_]);
 						}
 						$key_ = NAME_DELIMITER.$key_;
 					}
@@ -212,9 +206,9 @@ class CScreenDiscovery extends CScreenBase {
 				}
 			}
 
-			if ($druleid == 0 && $discovery_info) {
+			if ($discovery_info) {
 				$col = new CCol(
-					[bold($drule['name']), SPACE.'('._n('%d device', '%d devices', count($discovery_info)).')']
+					[bold($drule['name']), NBSP(), '('._n('%d device', '%d devices', count($discovery_info)).')']
 				);
 				$col->setColSpan(count($services) + 3);
 
@@ -223,15 +217,15 @@ class CScreenDiscovery extends CScreenBase {
 			order_result($discovery_info, $sort_field, $sort_order);
 
 			foreach ($discovery_info as $ip => $h_data) {
-				$dns = $h_data['dns'] == '' ? '' : ' ('.$h_data['dns'].')';
+				$dns = ($h_data['dns'] === '') ? '' : ' ('.$h_data['dns'].')';
 				$row = [
-					$h_data['type'] == 'primary'
+					($h_data['type'] === 'primary')
 						? (new CSpan($ip.$dns))->addClass($h_data['class'])
-						: new CSpan(SPACE.SPACE.$ip.$dns),
+						: new CSpan([NBSP(), NBSP(), $ip.$dns]),
 					new CSpan(array_key_exists('host', $h_data) ? $h_data['host'] : ''),
 					(new CSpan((($h_data['time'] == 0 || $h_data['type'] === 'slave')
 						? ''
-						: convert_units(['value' => time() - $h_data['time'], 'units' => 'uptime'])))
+						: convertUnits(['value' => time() - $h_data['time'], 'units' => 'uptime'])))
 					)
 						->addClass($h_data['class'])
 				];
