@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -180,7 +180,7 @@ if ($data['vendor']) {
 	]));
 }
 
-$tabs->addTab('tmplTab', _('Templates'), $template_tab, false);
+$tabs->addTab('tmplTab', _('Template'), $template_tab);
 
 // tags
 $tabs->addTab('tags-tab', _('Tags'), new CPartial('configuration.tags.tab', [
