@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -51,24 +51,25 @@
 </script>
 <script>
 	function setAuthTypeLabel() {
-		if (jQuery('#authtype').val() == <?= json_encode(ITEM_AUTHTYPE_PUBLICKEY) ?>
-				&& jQuery('#type').val() == <?= json_encode(ITEM_TYPE_SSH) ?>) {
-			jQuery('#row_password label').html(<?= json_encode(_('Key passphrase')) ?>);
-		}
-		else {
-			jQuery('#row_password label').html(<?= json_encode(_('Password')) ?>);
+		if (document.getElementById('type').value == <?= ITEM_TYPE_SSH ?>) {
+			document.getElementById('js-item-password-label').innerText =
+					document.getElementById('authtype').value == <?= ITEM_AUTHTYPE_PUBLICKEY ?>
+				? <?= json_encode(_('Key passphrase')) ?>
+				: <?= json_encode(_('Password')) ?>;
 		}
 	}
 
 	const item_form = {
-		init({interfaces, value_type_by_keys, keys_by_item_type, testable_item_types, field_switches, interface_types}) {
+		init({interfaces, value_type_by_keys, keys_by_item_type, testable_item_types, field_switches, interface_types,
+				discovered_item}) {
 			this.interfaces = interfaces;
 			this.testable_item_types = testable_item_types;
 			this.field_switches = field_switches;
 			this.interface_types = interface_types;
+			this.discovered_item = discovered_item === undefined ? false : discovered_item;
 
 			if (typeof value_type_by_keys !== 'undefined' && typeof keys_by_item_type !== 'undefined') {
-				item_type_lookup.init(value_type_by_keys, keys_by_item_type);
+				item_type_lookup.init(value_type_by_keys, keys_by_item_type, this.discovered_item);
 			}
 		}
 	}
@@ -78,7 +79,9 @@
 		var testable_item_types = item_form.testable_item_types,
 			type = parseInt(jQuery('#type').val(), 10),
 			key = jQuery('#key').val(),
-			is_http_agent_type = (type == <?= ITEM_TYPE_HTTPAGENT ?>);
+			interface_optional = <?= json_encode(
+					array_keys(itemTypeInterface(), INTERFACE_TYPE_OPT)
+				) ?>.indexOf(type) != -1;
 
 		if (type == <?= ITEM_TYPE_SIMPLE ?> && (key.substr(0, 7) === 'vmware.' || key.substr(0, 8) === 'icmpping')) {
 			jQuery('#test_item').prop('disabled', true);
@@ -104,8 +107,8 @@
 			);
 		}
 
-		$('label[for=interfaceid]').toggleClass('<?= ZBX_STYLE_FIELD_LABEL_ASTERISK ?>', !is_http_agent_type);
-		$('input[name=interfaceid]').prop('aria-required', !is_http_agent_type);
+		$('label[for=interfaceid]').toggleClass('<?= ZBX_STYLE_FIELD_LABEL_ASTERISK ?>', !interface_optional);
+		$('input[name=interfaceid]').prop('aria-required', !interface_optional);
 	}
 
 	jQuery(document).ready(function($) {
@@ -244,7 +247,7 @@
 		inferred_type: null,
 		item_type: null,
 
-		init(value_type_by_keys, keys_by_item_type) {
+		init(value_type_by_keys, keys_by_item_type, discovered_item) {
 			this.value_type_by_keys = value_type_by_keys;
 			this.keys_by_item_type = keys_by_item_type;
 			this.form = document.querySelector('#item-form, #item-prototype-form');
@@ -252,6 +255,7 @@
 			this.item_tab_type_field = this.form.querySelector('[name=value_type]');
 			this.preprocessing_tab_type_field = this.form.querySelector('[name=value_type_steps]');
 			this.item_type = this.form.querySelector('[name=type]');
+			this.discovered_item = discovered_item;
 
 			this.updateKeyTypeSuggestions();
 
@@ -265,7 +269,7 @@
 				this.updateHintDisplay();
 
 				// 'Do not keep trends' for Calculated with string-types of information is forced on Item save.
-				if (this.item_type.value == <?=ITEM_TYPE_CALCULATED ?>) {
+				if (this.item_type.value == <?=ITEM_TYPE_CALCULATED ?> && !this.discovered_item) {
 					if (e.target.value == <?= ITEM_VALUE_TYPE_FLOAT ?>
 							|| e.target.value == <?= ITEM_VALUE_TYPE_UINT64 ?>) {
 						this.form.querySelector('#trends_mode_1').disabled = false;
