@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -86,7 +86,6 @@ function createFontSelect(string $name): CSelect {
 			->toString()
 	?>
 	<?= (new CForm())
-			->cleanItems()
 			->setName('selementForm')
 			->setId('selementForm')
 			->addItem(
@@ -140,9 +139,10 @@ function createFontSelect(string $name): CSelect {
 					)
 					->addRow(_('Label'),
 						(new CTextArea('label'))
+							->setId('elementLabel')
 							->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 							->setRows(2)
-							->setId('elementLabel')
+							->disableSpellcheck()
 					)
 					->addRow(new CLabel(_('Label location'), 'label-label-location'),
 						(new CSelect('label_location'))
@@ -180,12 +180,14 @@ function createFontSelect(string $name): CSelect {
 								->setId('triggerContainer')
 								->setAttribute('style', 'width: 100%;')
 								->addClass('ui-sortable')
+								->addClass('trigger-list')
 						]))
 							->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
 							->setAttribute('style', 'min-width: '.ZBX_TEXTAREA_BIG_WIDTH.'px;')
 					], 'triggerListRow')
-					->addRow((new CLabel(_('New triggers'), 'elementNameTriggers_ms')),
-						(new CDiv([
+					->addRow(
+						(new CLabel(_('New triggers'), 'elementNameTriggers_ms')),
+						[
 							(new CMultiSelect([
 								'name' => 'elementNameTriggers',
 								'object_name' => 'triggers',
@@ -201,36 +203,23 @@ function createFontSelect(string $name): CSelect {
 									]
 								]
 							]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
-							new CDiv(
-								(new CButton(null, _('Add')))
-									->addClass(ZBX_STYLE_BTN_LINK)
-									->setId('newSelementTriggers')
-						)]))
-							->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
-							->setAttribute('style', 'min-width: '.ZBX_TEXTAREA_BIG_WIDTH.'px;'),
+							(new CButton(null, _('Add')))
+								->addClass(ZBX_STYLE_BTN_LINK)
+								->setId('newSelementTriggers')
+								->addStyle('margin-top: 5px;')
+						],
 						'triggerSelectRow'
 					)
-					->addRow((new CLabel(_('Map'), 'elementName'))->setAsteriskMark(), [
-						(new CTextBox('elementName'))
-							->setReadonly(true)
-							->setId('elementNameMap')
+					->addRow((new CLabel(_('Map'), 'elementNameMap_ms'))->setAsteriskMark(),
+						(new CMultiSelect([
+							'name' => 'elementNameMap',
+							'object_name' => 'sysmaps',
+							'multiple' => false
+						]))
 							->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 							->setAriaRequired(),
-						(new CVar('elements[0][sysmapid]', 0, 'sysmapid')),
-						(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-						(new CButton(null, _('Select')))
-							->addClass(ZBX_STYLE_BTN_GREY)
-							->onClick(
-								'return PopUp("popup.generic", jQuery.extend('.json_encode([
-									'srctbl' => 'sysmaps',
-									'srcfld1' => 'sysmapid',
-									'srcfld2' => 'name',
-									'dstfrm' => 'selementForm',
-									'dstfld1' => 'sysmapid',
-									'dstfld2' => 'elementNameMap'
-								]).', {excludeids: [#{sysmapid}]}), {dialogue_class: "modal-popup-generic"});'
-							)
-					], 'mapSelectRow')
+						'mapSelectRow'
+					)
 					->addRow(_('Tags'),
 						(new CDiv([
 							(new CTable())
@@ -359,7 +348,6 @@ function createFontSelect(string $name): CSelect {
 			->setId('shapeDragHandler')
 			->toString().
 		(new CForm())
-			->cleanItems()
 			->setName('shapeForm')
 			->setId('shapeForm')
 			->addVar('sysmap_shapeid', '')
@@ -518,7 +506,6 @@ function createFontSelect(string $name): CSelect {
 			->setId('massShapeDragHandler')
 			->toString().
 		(new CForm())
-			->cleanItems()
 			->setName('shapeForm')
 			->setId('massShapeForm')
 			->addItem(
@@ -649,7 +636,6 @@ function createFontSelect(string $name): CSelect {
 			->toString()
 	?>
 	<?= (new CForm())
-			->cleanItems()
 			->setId('massForm')
 			->addItem(
 				(new CFormList())
@@ -668,9 +654,10 @@ function createFontSelect(string $name): CSelect {
 							->setId('chkboxLabel')
 							->setLabel(_('Label')),
 						(new CTextArea('label'))
+							->setId('massLabel')
 							->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 							->setRows(2)
-							->setId('massLabel')
+							->disableSpellcheck()
 					)
 					->addRow(
 						(new CCheckBox('chkbox_label_location'))
@@ -779,16 +766,16 @@ function createFontSelect(string $name): CSelect {
 		->toString()
 	?>
 	<?= (new CForm())
-			->cleanItems()
 			->setId('linkForm')
 			->addVar('selementid1', '')
 			->addItem(
 				(new CFormList())
 					->addRow(_('Label'),
 						(new CTextArea('label'))
+							->setId('linklabel')
 							->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 							->setRows(2)
-							->setId('linklabel')
+							->disableSpellcheck()
 					)
 					->addRow(new CLabel(_('Connect to'), 'label-selementid2'), (new CSelect('selementid2'))
 							->setFocusableElementId('label-selementid2')
@@ -929,13 +916,10 @@ function createFontSelect(string $name): CSelect {
 <script type="text/x-jquery-tmpl" id="selementFormTriggers">
 	<?= (new CRow([
 			(new CCol([
-				(new CDiv())
-					->addClass(ZBX_STYLE_DRAG_ICON)
-					->addStyle('top: 0px;'),
+				(new CDiv())->addClass(ZBX_STYLE_DRAG_ICON),
 				(new CSpan())->addClass('ui-icon ui-icon-arrowthick-2-n-s move '.ZBX_STYLE_TD_DRAG_ICON)
 			]))->addClass(ZBX_STYLE_TD_DRAG_ICON),
 			(new CCol([(new CDiv('#{name}'))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)]))
-				->addStyle('padding: 0 5px;')
 				->addClass('#{class_name}'),
 			(new CCol([
 				(new CVar('element_id[#{triggerid}]', '#{triggerid}')),
