@@ -1,6 +1,6 @@
 /*
  ** Zabbix
- ** Copyright (C) 2001-2020 Zabbix SIA
+ ** Copyright (C) 2001-2024 Zabbix SIA
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ jQuery(function ($) {
 		var value;
 
 		for (value = options.min; value < options.max; value += options.step) {
-			$('<option/>').attr('value', value).appendTo(datalist);
+			$('<option>', {value: value}).appendTo(datalist);
 		}
 	}
 
@@ -45,11 +45,11 @@ jQuery(function ($) {
 		init: function() {
 			var tmpl = $('<div class="range-control">' +
 					'<div>' +
-						'<div class="range-control-track"/>' +
-						'<div class="range-control-progress"/>' +
-						'<datalist/>' +
-						'<div class="range-control-thumb"/>' +
-						'<input type="range"/>' +
+						'<div class="range-control-track"></div>' +
+						'<div class="range-control-progress"></div>' +
+						'<datalist></datalist>' +
+						'<div class="range-control-thumb"></div>' +
+						'<input type="range">' +
 					'</div>' +
 				'</div>');
 
@@ -104,7 +104,17 @@ jQuery(function ($) {
 					.insertBefore($input);
 
 				$input
-					.change(function() {$range.val(this.value); updateHandler();})
+					.change(function() {
+						const value = Number(this.value);
+
+						if (Number.isInteger(value)) {
+							$range[0].value = value;
+							updateHandler();
+						}
+						else {
+							this.value = $range[0].value;
+						}
+					})
 					.appendTo($control);
 			});
 		},
