@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -52,6 +52,7 @@ class CDashboardPage extends CBaseComponent {
 		can_edit_dashboards,
 		time_period,
 		dynamic_hostid,
+		csrf_token = null,
 		unique_id
 	}) {
 		super(document.createElement('div'));
@@ -81,6 +82,7 @@ class CDashboardPage extends CBaseComponent {
 		this._can_edit_dashboards = can_edit_dashboards;
 		this._time_period = time_period;
 		this._dynamic_hostid = dynamic_hostid;
+		this._csrf_token = csrf_token;
 		this._unique_id = unique_id;
 
 		this._init();
@@ -92,11 +94,6 @@ class CDashboardPage extends CBaseComponent {
 
 		this._widgets = new Map();
 
-		this._original_properties = {
-			name: this._data.name,
-			display_period: this._data.display_period
-		};
-
 		this._grid_min_rows = 0;
 		this._grid_pad_rows = 2;
 
@@ -270,17 +267,7 @@ class CDashboardPage extends CBaseComponent {
 	}
 
 	isUnsaved() {
-		if (this._is_unsaved) {
-			return true;
-		}
-
-		for (const [name, value] of Object.entries(this._original_properties)) {
-			if (value != this._data[name]) {
-				return true;
-			}
-		}
-
-		return false;
+		return this._is_unsaved;
 	}
 
 	// Data interface methods.
@@ -323,19 +310,26 @@ class CDashboardPage extends CBaseComponent {
 		return null;
 	}
 
-	addWidget({type, name, view_mode, fields, configuration, widgetid, pos, is_new, rf_rate, unique_id}) {
-		const widget = this._createWidget(this._widget_defaults[type].js_class, {
-			type,
-			name,
-			view_mode,
-			fields,
-			configuration,
-			widgetid,
-			pos,
-			is_new,
-			rf_rate,
-			unique_id
-		});
+	addWidget({type, name, view_mode, fields, widgetid, pos, is_new, rf_rate, unique_id}) {
+		let widget;
+
+		if (type in this._widget_defaults) {
+			widget = this._createWidget(eval(this._widget_defaults[type].js_class), {
+				type,
+				name,
+				view_mode,
+				fields,
+				defaults: this._widget_defaults[type],
+				widgetid,
+				pos,
+				is_new,
+				rf_rate,
+				unique_id
+			});
+		}
+		else {
+			widget = this._createInaccessibleWidget({widgetid, pos, unique_id});
+		}
 
 		this._doAddWidget(widget);
 
@@ -399,21 +393,18 @@ class CDashboardPage extends CBaseComponent {
 	}
 
 	replaceWidget(widget, widget_data) {
-		this._is_unsaved = true;
-
 		this.deleteWidget(widget, {is_batch_mode: true});
 
 		return this.addWidget(widget_data);
 	}
 
-	_createWidget(js_class, {type, name, view_mode, fields, configuration, widgetid, pos, is_new, rf_rate, unique_id}) {
-		return new (eval(js_class))({
+	_createWidget(widget_class, {type, name, view_mode, fields, defaults, widgetid, pos, is_new, rf_rate, unique_id}) {
+		return new widget_class({
 			type,
 			name,
 			view_mode,
 			fields,
-			configuration,
-			defaults: this._widget_defaults[type],
+			defaults,
 			widgetid,
 			pos,
 			is_new,
@@ -433,18 +424,34 @@ class CDashboardPage extends CBaseComponent {
 			can_edit_dashboards: this._can_edit_dashboards,
 			time_period: this._time_period,
 			dynamic_hostid: this._dynamic_hostid,
-			scope_id: this._unique_id,
+			csrf_token: this._csrf_token,
+			unique_id
+		});
+	}
+
+	_createInaccessibleWidget({widgetid, pos, unique_id}) {
+		return this._createWidget(CWidgetInaccessible, {
+			type: 'inaccessible',
+			view_mode: ZBX_WIDGET_VIEW_MODE_HIDDEN_HEADER,
+			fields: {},
+			defaults: {
+				name: t('Inaccessible widget')
+			},
+			widgetid,
+			pos,
+			is_new: false,
+			rf_rate: 0,
 			unique_id
 		});
 	}
 
 	_createPastePlaceholderWidget({type, name, view_mode, pos, unique_id}) {
-		return this._createWidget('CWidgetPastePlaceholder', {
-			type,
+		return this._createWidget(CWidgetPastePlaceholder, {
+			type: 'paste-placeholder',
 			name,
 			view_mode,
 			fields: {},
-			configuration: {},
+			defaults: this._widget_defaults[type],
 			widgetid: null,
 			pos,
 			is_new: false,
@@ -697,10 +704,10 @@ class CDashboardPage extends CBaseComponent {
 		}
 
 		return true;
-	};
+	}
 
 	_resizeGrid(min_rows = null) {
-		if (min_rows == 0) {
+		if (min_rows === 0) {
 			this._grid_min_rows = 0;
 		}
 		else if (min_rows !== null) {
@@ -709,6 +716,12 @@ class CDashboardPage extends CBaseComponent {
 
 		let num_rows = Math.max(this._grid_min_rows, this._getNumOccupiedRows());
 
+		if (!this._is_edit_mode && num_rows === 0) {
+			this._dashboard_grid.style.height = '';
+
+			return;
+		}
+
 		let height = this._cell_height * num_rows;
 
 		if (this._is_edit_mode) {
@@ -723,7 +736,7 @@ class CDashboardPage extends CBaseComponent {
 			}
 			while (!element.classList.contains('wrapper'));
 
-			height = Math.max(height, min_height);
+			height = Math.min(Math.max(height, min_height), this._cell_height * this._max_rows);
 		}
 
 		this._dashboard_grid.style.height = `${height}px`;
