@@ -1,6 +1,6 @@
 /*
  ** Zabbix
- ** Copyright (C) 2001-2022 Zabbix SIA
+ ** Copyright (C) 2001-2024 Zabbix SIA
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -119,7 +119,7 @@
 				params_index = type_params[screen.resourcetype] ? screen.resourcetype : 'default',
 				self = this;
 
-			const ajax_url = new Curl('jsrpc.php', false);
+			const ajax_url = new Curl('jsrpc.php');
 			const post_data = {
 				type: 9, // PAGE_TYPE_TEXT
 				method: 'screen.get',
@@ -152,7 +152,7 @@
 					self.refreshImg(id, function() {
 						$('a', '#flickerfreescreen_' + id).each(function() {
 								var obj = $(this),
-								url = new Curl(obj.attr('href'), false);
+								url = new Curl(obj.attr('href'));
 
 								url.setArgument('from', screen.timeline.from);
 								url.setArgument('to', screen.timeline.to);
@@ -337,7 +337,7 @@
 
 				$('img', '#flickerfreescreen_' + id).each(function() {
 					var domImg = $(this),
-						url = new Curl(domImg.attr('src'), false),
+						url = new Curl(domImg.attr('src')),
 						zbx_sbox = domImg.data('zbx_sbox');
 
 					if (zbx_sbox && zbx_sbox.prevent_refresh) {
