@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -36,16 +36,27 @@ $fields = [
 	'tpl_triggerid' =>		[T_ZBX_INT,			O_OPT,	P_SYS,			DB_ID,		null],
 	'triggerid' =>			[T_ZBX_INT,			O_OPT,	P_SYS|P_NZERO,	DB_ID,		null],
 	// filter
-	'filter_groups' =>		[T_ZBX_INT,			O_OPT,	P_SYS,			DB_ID,		null],
-	'filter_hostids' =>		[T_ZBX_INT,			O_OPT,	P_SYS,			DB_ID,		null],
-	'filter_templateid' =>	[T_ZBX_INT,			O_OPT,	P_SYS,			DB_ID,		null],
-	'filter_rst'=>			[T_ZBX_STR,			O_OPT,	P_SYS,			null,		null],
-	'filter_set' =>			[T_ZBX_STR,			O_OPT,	P_SYS,			null,		null],
-	'from' =>				[T_ZBX_RANGE_TIME,	O_OPT,	P_SYS,			null,		null],
-	'to' =>					[T_ZBX_RANGE_TIME,	O_OPT,	P_SYS,			null,		null]
+	'filter_groupid' =>		[T_ZBX_INT,			O_OPT,	P_SYS,				DB_ID,	null],
+	'filter_groups' =>		[T_ZBX_INT,			O_OPT,	P_SYS|P_ONLY_ARRAY,	DB_ID,	null],
+	'filter_hostids' =>		[T_ZBX_INT,			O_OPT,	P_SYS|P_ONLY_ARRAY,	DB_ID,	null],
+	'filter_templateid' =>	[T_ZBX_INT,			O_OPT,	P_SYS,				DB_ID,	null],
+	'filter_rst'=>			[T_ZBX_STR,			O_OPT,	P_SYS,				null,	null],
+	'filter_set' =>			[T_ZBX_STR,			O_OPT,	P_SYS,				null,	null],
+	'from' =>				[T_ZBX_RANGE_TIME,	O_OPT,	P_SYS,				null,	null],
+	'to' =>					[T_ZBX_RANGE_TIME,	O_OPT,	P_SYS,				null,	null]
 ];
 check_fields($fields);
-validateTimeSelectorPeriod(getRequest('from'), getRequest('to'));
+
+if (hasRequest('from') || hasRequest('to')) {
+	validateTimeSelectorPeriod(
+		hasRequest('from') ? getRequest('from') : null,
+		hasRequest('to') ? getRequest('to') : null
+	);
+}
+
+$timeselector_from = getRequest('from', CProfile::get('web.avail_report.filter.from',
+	'now-'.CSettingsHelper::get(CSettingsHelper::PERIOD_DEFAULT)));
+$timeselector_to = getRequest('to', CProfile::get('web.avail_report.filter.to', 'now'));
 
 $report_mode = getRequest('mode', CProfile::get('web.avail_report.mode', AVAILABILITY_REPORT_BY_HOST));
 CProfile::update('web.avail_report.mode', $report_mode, PROFILE_TYPE_INT);
@@ -57,7 +68,7 @@ if ($report_mode == AVAILABILITY_REPORT_BY_TEMPLATE) {
 	if (getRequest('hostgroupid') && !isReadableHostGroups([getRequest('hostgroupid')])) {
 		access_deny();
 	}
-	if (getRequest('filter_groups') && !isReadableTemplateGroups([getRequest('filter_groups')])) {
+	if (getRequest('filter_groupid') && !isReadableTemplateGroups([getRequest('filter_groupid')])) {
 		access_deny();
 	}
 	if (getRequest('filter_templateid') && !isReadableTemplates([getRequest('filter_templateid')])) {
@@ -74,14 +85,6 @@ if ($report_mode == AVAILABILITY_REPORT_BY_TEMPLATE) {
 		}
 	}
 }
-else {
-	if (getRequest('filter_groupid') && !isReadableHostGroups([getRequest('filter_groupid')])) {
-		access_deny();
-	}
-	if (getRequest('filter_hostid') && !isReadableHosts([getRequest('filter_hostid')])) {
-		access_deny();
-	}
-}
 if (getRequest('triggerid') && !isReadableTriggers([getRequest('triggerid')])) {
 	access_deny();
 }
@@ -93,12 +96,14 @@ $key_prefix = 'web.avail_report.'.$report_mode;
 
 if (hasRequest('filter_set')) {
 	if ($report_mode == AVAILABILITY_REPORT_BY_TEMPLATE) {
-		CProfile::update($key_prefix.'.groupid', getRequest('filter_groups', 0), PROFILE_TYPE_ID);
+		CProfile::update($key_prefix.'.groupid', getRequest('filter_groupid', 0), PROFILE_TYPE_ID);
 		CProfile::update($key_prefix.'.hostid', getRequest('filter_templateid', 0), PROFILE_TYPE_ID);
 		CProfile::update($key_prefix.'.tpl_triggerid', getRequest('tpl_triggerid', 0), PROFILE_TYPE_ID);
 		CProfile::update($key_prefix.'.hostgroupid', getRequest('hostgroupid', 0), PROFILE_TYPE_ID);
 	}
 	else {
+		CProfile::update('web.avail_report.filter.from', $timeselector_from, PROFILE_TYPE_STR);
+		CProfile::update('web.avail_report.filter.to', $timeselector_to, PROFILE_TYPE_STR);
 		CProfile::updateArray($key_prefix.'.groupids', getRequest('filter_groups', []), PROFILE_TYPE_ID);
 		CProfile::updateArray($key_prefix.'.hostids', getRequest('filter_hostids', []), PROFILE_TYPE_ID);
 	}
@@ -120,7 +125,7 @@ elseif (hasRequest('filter_rst')) {
 $data['filter'] = ($report_mode == AVAILABILITY_REPORT_BY_TEMPLATE)
 	? [
 		// 'Template group' field.
-		'groups' => getRequest('filter_groups', CProfile::get($key_prefix.'.groupid', 0)),
+		'groups' => getRequest('filter_groupid', CProfile::get($key_prefix.'.groupid', 0)),
 		// 'Template' field.
 		'hostids' => getRequest('filter_templateid', CProfile::get($key_prefix.'.hostid', 0)),
 		// 'Template trigger' field.
@@ -135,15 +140,6 @@ $data['filter'] = ($report_mode == AVAILABILITY_REPORT_BY_TEMPLATE)
 		'hostids' => CProfile::getArray($key_prefix.'.hostids', getRequest('filter_hostids', []))
 	];
 
-// Get time selector filter values.
-$timeselector_options = [
-	'profileIdx' => 'web.avail_report.filter',
-	'profileIdx2' => 0,
-	'from' => getRequest('from'),
-	'to' => getRequest('to')
-];
-updateTimeSelectorPeriod($timeselector_options);
-
 /*
  * Header
  */
@@ -156,7 +152,7 @@ $triggerData = isset($_REQUEST['triggerid'])
 	])
 	: null;
 
-$reportWidget = (new CWidget())
+$html_page = (new CHtmlPage())
 	->setTitle(_('Availability report'))
 	->setDocUrl(CDocHelper::getUrl(CDocHelper::REPORT2));
 
@@ -167,7 +163,7 @@ if ($triggerData) {
 	$triggerData['hostid'] = $host['hostid'];
 	$triggerData['hostname'] = $host['name'];
 
-	$reportWidget->setControls((new CTag('nav', true,
+	$html_page->setControls((new CTag('nav', true,
 		(new CList())
 			->addItem(new CLink($triggerData['hostname'], (new CUrl('report2.php'))
 				->setArgument('page', CPagerHelper::loadPage('report2.php', null))
@@ -180,7 +176,7 @@ if ($triggerData) {
 	$table = (new CTableInfo())
 		->addRow(new CImg('chart4.php?triggerid='.$_REQUEST['triggerid']));
 
-	$reportWidget->addItem(BR())
+	$html_page->addItem(BR())
 		->addItem($table)
 		->show();
 }
@@ -195,8 +191,7 @@ else {
 		->addOption(new CSelectOption(AVAILABILITY_REPORT_BY_HOST, _('By host')))
 		->addOption(new CSelectOption(AVAILABILITY_REPORT_BY_TEMPLATE, _('By trigger template')));
 
-	$reportWidget->setControls((new CForm('get'))
-		->cleanItems()
+	$html_page->setControls((new CForm('get'))
 		->setAttribute('aria-label', _('Main filter'))
 		->addItem((new CList())
 			->addItem([
@@ -212,7 +207,12 @@ else {
 	 * Filter
 	 */
 	$data['filter'] += [
-		'timeline' => getTimeSelectorPeriod($timeselector_options),
+		'timeline' => getTimeSelectorPeriod([
+			'profileIdx' => 'web.avail_report.filter',
+			'profileIdx2' => 0,
+			'from' => $timeselector_from,
+			'to' => $timeselector_to
+		]),
 		'active_tab' => CProfile::get('web.avail_report.filter.active', 1)
 	];
 
@@ -375,7 +375,7 @@ else {
 			$triggers = [];
 		}
 
-		$select_filter_groupid = (new CSelect('filter_groups'))
+		$select_filter_groupid = (new CSelect('filter_groupid'))
 			->setAttribute('autofocus', 'autofocus')
 			->setValue($data['filter']['groups'])
 			->setFocusableElementId('filter-groups')
@@ -471,8 +471,9 @@ else {
 					'object_name' => 'hosts',
 					'data' => $data['filter']['hostids'],
 					'popup' => [
-						'filter_preselect_fields' => [
-							'hostgroups' => 'filter_groups_'
+						'filter_preselect' => [
+							'id' => 'filter_groups_',
+							'submit_as' => 'groupid'
 						],
 						'parameters' => [
 							'srctbl' => 'hosts',
@@ -493,14 +494,15 @@ else {
 	}
 	unset($trigger);
 
-	$reportWidget->addItem(
+	$html_page->addItem(
 		(new CFilter())
 			->setResetUrl(new CUrl('report2.php'))
 			->setProfile($data['filter']['timeline']['profileIdx'])
 			->setActiveTab($data['filter']['active_tab'])
 			->addFormItem((new CVar('mode', $report_mode))->removeId())
 			->addTimeSelector($data['filter']['timeline']['from'], $data['filter']['timeline']['to'], true,
-				ZBX_DATE_TIME)
+				'web.avail_report.filter', ZBX_DATE_TIME
+			)
 			->addFilterTab(_('Filter'), [$filter_column])
 	);
 
@@ -522,21 +524,13 @@ else {
 			$data['filter']['timeline']['to_ts']
 		);
 
-		$url = (new CUrl('report2.php'))->setArgument('triggerid', $trigger['triggerid']);
-		if ($report_mode == AVAILABILITY_REPORT_BY_TEMPLATE) {
-			$url->setArgument('filter_templateid', $data['filter']['hostids']);
-		}
-		else {
-			$url->setArgument('filter_hostids', $trigger['hosts'][0]['hostid']);
-		}
-
 		$triggerTable->addRow([
 			$trigger['host_name'],
 			$allowed_ui_problems
 				? new CLink($trigger['description'],
 					(new CUrl('zabbix.php'))
 						->setArgument('action', 'problem.view')
-						->setArgument('filter_name', '')
+						->setArgument('filter_set', '1')
 						->setArgument('triggerids', [$trigger['triggerid']])
 				)
 				: $trigger['description'],
@@ -546,7 +540,7 @@ else {
 			($availability['false'] < 0.00005)
 				? ''
 				: (new CSpan(sprintf('%.4f%%', $availability['false'])))->addClass(ZBX_STYLE_GREEN),
-			new CLink(_('Show'), $url)
+			new CLink(_('Show'), (new CUrl('report2.php'))->setArgument('triggerid', $trigger['triggerid']))
 		]);
 	}
 
@@ -562,7 +556,7 @@ else {
 	);
 	zbx_add_post_js('timeControl.processObjects();');
 
-	$reportWidget
+	$html_page
 		->addItem([$triggerTable, $paging])
 		->show();
 }
